@@ -39,7 +39,7 @@ sub meta_merge {
 	resources	=> {
 	    bugtracker	=> {
                 web	=> 'https://rt.cpan.org/Public/Dist/Display.html?Name=Geo-Coder-Geocoder-US',
-                mailto  => 'wyant@cpan.org',
+#                mailto  => 'wyant@cpan.org',
             },
 	    license	=> 'http://dev.perl.org/licenses/',
 	    repository	=> {
@@ -60,7 +60,7 @@ sub notice {
 The web site that this module in a front-end to, http://geocoder.us/,
 disappeared in late 2015. Without the web site, this module does
 nothing. Because this web site or a readonable facsimile has not not
-reappeared by mid-2016, this module IS BEING RETRACTED. See the POD for
+reappeared by mid-2016, this module HAS BEEN RETRACTED. See the POD for
 the detailed plan.
 
 EOD
@@ -204,7 +204,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010-2017 by Thomas R. Wyant, III
+Copyright (C) 2010-2018 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
