@@ -11,12 +11,12 @@ use Text::CSV;
 use URI;
 # use URI::Escape qw{ uri_escape };
 
-our $VERSION = '0.009';
+our $VERSION = '0.010';
 
 use constant RETRACTION_MESSAGE =>
-	'Geo::Coder::Geocoder::US is being retracted, because the underlying web site no longer exists';
+	'Geo::Coder::Geocoder::US has been retracted, because the underlying web site no longer exists';
 
-Carp::cluck( RETRACTION_MESSAGE );
+Carp::confess( RETRACTION_MESSAGE );
 {
 
 ##  my %valid_arg = map { $_ => 1 } qw{ debug interface ua };
@@ -446,7 +446,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2011-2017 by Thomas R. Wyant, III
+Copyright (C) 2011-2018 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
